/*
 * MikroSDK - MikroE Software Development Kit
 * Copyright (c) 2019, MikroElektronika - www.mikroe.com
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/*!
 * \file
 *
 */

#include "digivref.h"

// ------------------------------------------------------------- PRIVATE MACROS 

#define DIGIVREF_DUMMY 0

// ------------------------------------------------ PUBLIC FUNCTION DEFINITIONS

void digivref_cfg_setup ( digivref_cfg_t *cfg )
{
    // Communication gpio pins 

    cfg->sck = HAL_PIN_NC;
    cfg->miso = HAL_PIN_NC;
    cfg->mosi = HAL_PIN_NC;
    cfg->cs = HAL_PIN_NC;

    cfg->spi_speed = SPI_MEDIUM; 
    cfg->spi_mode = SPI_MODE_0;
}

DIGIVREF_RETVAL digivref_init ( digivref_t *ctx, digivref_cfg_t *cfg )
{
    spi_master_config_t spi_cfg;

    spi_master_configure_default( &spi_cfg );
    spi_cfg.mode        = cfg->spi_mode;
    spi_cfg.speed       = cfg->spi_speed;
    spi_cfg.pins.sck    = cfg->sck;
    spi_cfg.pins.miso   = cfg->miso;
    spi_cfg.pins.mosi   = cfg->mosi;
    spi_cfg.chip_select = cfg->cs;

    if (  spi_master_open( &ctx->spi, &spi_cfg ) != SPI_SUCCESS )
    {
        return DIGIVREF_INIT_ERROR;
    }

    spi_master_set_dummy_data( &ctx->spi, DIGIVREF_DUMMY );

    return DIGIVREF_OK;
}

void digivref_generic_transfer ( digivref_t *ctx, spi_master_transfer_data_t *block )
{
    spi_master_start( &ctx->spi );
    spi_master_transfer( &ctx->spi, block );
    spi_master_stop( &ctx->spi );    
}

void digivref_set_output_voltage ( digivref_t *ctx, uint8_t v_ref )
{
    uint8_t tmp[ 2 ];

    tmp[ 0 ] = 0x00;
    tmp[ 1 ] = v_ref;

    spi_master_start( &ctx->spi );
    spi_master_write( &ctx->spi, tmp[ 0 ] );
    spi_master_write( &ctx->spi, tmp[ 1 ] );
    spi_master_stop( &ctx->spi ); 
}

// ------------------------------------------------------------------------- END

